@@ -15,7 +15,7 @@ import warnings
 from numba.core.errors import NumbaWarning
 warnings.filterwarnings("ignore", category=NumbaWarning)
 
-__version__ = "0.8.6"
+__version__ = "0.8.7"
 
 """
 Copyright 2018, Alexander J. Tarashansky, All rights reserved.
@@ -859,7 +859,7 @@ class SAM(object):
         sparse_pca=False,
         proj_kwargs={},
         seed = 0,
-        weight_mode='combined',
+        weight_mode='rms',
         components=None
     ):
         """Runs the Self-Assembling Manifold algorithm.
@@ -1248,7 +1248,7 @@ class SAM(object):
             umap_obj = umap.UMAP(metric=metric,random_state=seed, **kwargs)
             umap2d = umap_obj.fit_transform(X)
             self.adata.obsm["X_umap"] = umap2d
-            self.umap_obj = umap_obj
+            return umap_obj
         else:
             umap_obj = umap.UMAP(metric=metric,random_state=seed, **kwargs)
             dt = umap_obj.fit_transform(X)
